@@ -11,7 +11,6 @@ lists.
 """
 
 import concurrent.futures
-import io
 import os
 
 import bs4
@@ -39,7 +38,7 @@ def match_proxy(proxy: str) -> bool:
 
     Note:
         If ``proxy`` is ``script``, then it
-        will always return ``True``.
+        will always return :data:`True`.
 
     See Also:
         * :data:`darc.const.PROXY_WHITE_LIST`
@@ -50,14 +49,14 @@ def match_proxy(proxy: str) -> bool:
     if proxy == 'script':
         return True
 
-    # any matching white list
-    if proxy in PROXY_WHITE_LIST:
-        return False
-
     # any matching black list
     if proxy in PROXY_BLACK_LIST:
         return True
 
+    # any matching white list
+    if proxy in PROXY_WHITE_LIST:
+        return False
+
     # fallback
     return PROXY_FALLBACK
 
@@ -72,8 +71,8 @@ def match_host(host: str) -> bool:
         If ``host`` in  black list.
 
     Note:
-        If ``host`` is ``None``, then it
-        will always return ``True``.
+        If ``host`` is :data:`None`, then it
+        will always return :data:`True`.
 
     See Also:
         * :data:`darc.const.LINK_WHITE_LIST`
@@ -85,14 +84,14 @@ def match_host(host: str) -> bool:
     if host is None:
         return True
 
-    # any matching white list
-    if any(pattern.fullmatch(host) is not None for pattern in LINK_WHITE_LIST):
-        return False
-
     # any matching black list
     if any(pattern.fullmatch(host) is not None for pattern in LINK_BLACK_LIST):
         return True
 
+    # any matching white list
+    if any(pattern.fullmatch(host) is not None for pattern in LINK_WHITE_LIST):
+        return False
+
     # fallback
     return LINK_FALLBACK
 
@@ -112,48 +111,18 @@ def match_mime(mime: str) -> bool:
         * :data:`darc.const.MIME_FALLBACK`
 
     """
-    # any matching white list
-    if any(pattern.fullmatch(mime) is not None for pattern in MIME_WHITE_LIST):
-        return False
-
     # any matching black list
     if any(pattern.fullmatch(mime) is not None for pattern in MIME_BLACK_LIST):
         return True
 
+    # any matching white list
+    if any(pattern.fullmatch(mime) is not None for pattern in MIME_WHITE_LIST):
+        return False
+
     # fallback
     return MIME_FALLBACK
 
 
-def read_robots(link: str, text: str, host: typing.Optional[str] = None) -> typing.List[Link]:
-    """Read ``robots.txt`` to fetch link to sitemaps.
-
-    Args:
-        link: Original link to ``robots.txt``.
-        text: Content of ``robots.txt``.
-        host: Hostname of the URL to ``robots.txt``,
-            the value may not be same as in ``link``.
-
-    Returns:
-        List of link to sitemaps.
-
-    Note:
-        If the link to sitemap is not specified in
-        ``robots.txt`` [*]_, the fallback link
-        ``/sitemap.xml`` will be used.
-
-        .. [*] https://www.sitemaps.org/protocol.html#submit_robots
-
-    """
-    rp = RobotFileParser()
-    with io.StringIO(text) as file:
-        rp.parse(file)
-
-    sitemaps = rp.site_maps()
-    if sitemaps is None:
-        return [parse_link(urljoin(link, '/sitemap.xml'))]
-    return [parse_link(urljoin(link, sitemap), host=host) for sitemap in sitemaps]
-
-
 def check_robots(link: Link) -> bool:
     """Check if ``link`` is allowed in ``robots.txt``.
 
@@ -164,7 +133,7 @@ def check_robots(link: Link) -> bool:
         If ``link`` is allowed in ``robots.txt``.
 
     Note:
-        The root path of a URL will always return ``True``.
+        The root path of a URL will always return :data:`True`.
 
     """
     # bypass robots for root path
@@ -176,39 +145,13 @@ def check_robots(link: Link) -> bool:
         rp = RobotFileParser()
         with open(robots) as file:
             rp.parse(file)
-        return rp.can_fetch(requests.utils.default_user_agent(), link.url)
+
+        from darc.requests import default_user_agent  # pylint: disable=import-outside-toplevel
+        return rp.can_fetch(default_user_agent(), link.url)
     return True
 
 
-def get_sitemap(link: str, text: str, host: typing.Optional[str] = None) -> typing.List[Link]:
-    """Fetch link to other sitemaps from a sitemap.
-
-    Args:
-        link: Original link to the sitemap.
-        text: Content of the sitemap.
-        host: Hostname of the URL to the sitemap,
-            the value may not be same as in ``link``.
-
-    Returns:
-        List of link to sitemaps.
-
-    Note:
-        As specified in the sitemap protocol,
-        it may contain links to other sitemaps. [*]_
-
-        .. [*] https://www.sitemaps.org/protocol.html#index
-
-    """
-    sitemaps = list()
-    soup = bs4.BeautifulSoup(text, 'html5lib')
-
-    # https://www.sitemaps.org/protocol.html#index
-    for loc in soup.select('sitemapindex > sitemap > loc'):
-        sitemaps.append(urljoin(link, loc.text))
-    return [parse_link(sitemap, host=host) for sitemap in sitemaps]
-
-
-def _check_ng(temp_list: typing.List[str]) -> typing.List[str]:
+def _check_ng(temp_list: typing.List[Link]) -> typing.List[Link]:
     """Check content type of links through ``HEAD`` requests.
 
     Args:
@@ -227,8 +170,7 @@ def _check_ng(temp_list: typing.List[str]) -> typing.List[str]:
 
     session_map = dict()
     result_list = list()
-    for item in temp_list:
-        link = parse_link(item)
+    for link in temp_list:
         if match_host(link.host):
             continue
         if match_proxy(link.proxy):
@@ -240,7 +182,7 @@ def _check_ng(temp_list: typing.List[str]) -> typing.List[str]:
             session = request_session(link, futures=True)
             session_map[link.proxy] = session
 
-        result = session.head(link.url)
+        result = session.head(link.url, allow_redirects=True)
         result_list.append(result)
 
         print(f'[HEAD] Checking content type from {link.url}')
@@ -264,11 +206,12 @@ def _check_ng(temp_list: typing.List[str]) -> typing.List[str]:
 
         if match_mime(ct_type):
             continue
-        link_list.append(response.url)
+        temp_link = parse_link(response.request.url)
+        link_list.append(temp_link)
     return link_list
 
 
-def _check(temp_list: typing.List[str]) -> typing.List[str]:
+def _check(temp_list: typing.List[Link]) -> typing.List[Link]:
     """Check hostname and proxy type of links.
 
     Args:
@@ -278,7 +221,7 @@ def _check(temp_list: typing.List[str]) -> typing.List[str]:
         List of links matches the requirements.
 
     Note:
-        If :data:`~darc.const.CHECK_NG` is ``True``,
+        If :data:`~darc.const.CHECK_NG` is :data:`True`,
         the function will directly call :func:`~darc.parse._check_ng`
         instead.
 
@@ -291,51 +234,20 @@ def _check(temp_list: typing.List[str]) -> typing.List[str]:
         return _check_ng(temp_list)
 
     link_list = list()
-    for item in temp_list:
-        link = parse_link(item)
+    for link in temp_list:
         if match_host(link.host):
             continue
         if match_proxy(link.proxy):
             continue
-        link_list.append(link.url)
+        link_list.append(link)
     return link_list
 
 
-def read_sitemap(link: str, text: str, check: bool = CHECK) -> typing.Iterator[str]:
-    """Read sitemap.
-
-    Args:
-        link: Original link to the sitemap.
-        text: Content of the sitemap.
-        check: If perform checks on extracted links,
-            default to :data:`~darc.const.CHECK`.
-
-    Returns:
-        List of links extracted.
-
-    See Also:
-        * :func:`darc.parse._check`
-        * :func:`darc.parse._check_ng`
-
-    """
-    soup = bs4.BeautifulSoup(text, 'html5lib')
-
-    # https://www.sitemaps.org/protocol.html
-    temp_list = [urljoin(link, loc.text) for loc in soup.select('urlset > url > loc')]
-
-    # check content / proxy type
-    if check:
-        link_list = _check(temp_list)
-    else:
-        link_list = temp_list.copy()
-    yield from set(link_list)
-
-
 def get_content_type(response: typing.Response) -> str:
     """Get content type from ``response``.
 
     Args:
-        response (|Response|_): Response object.
+        response (:class:`requests.Response`): Response object.
 
     Returns:
         The content type from ``response``.
@@ -360,7 +272,7 @@ def get_content_type(response: typing.Response) -> str:
     return ct_type.casefold().split(';', maxsplit=1)[0].strip()
 
 
-def extract_links(link: str, html: typing.Union[str, bytes], check: bool = CHECK) -> typing.Iterator[str]:
+def extract_links(link: Link, html: typing.Union[str, bytes], check: bool = CHECK) -> typing.List[Link]:
     """Extract links from HTML document.
 
     Args:
@@ -370,7 +282,7 @@ def extract_links(link: str, html: typing.Union[str, bytes], check: bool = CHECK
             default to :data:`~darc.const.CHECK`.
 
     Returns:
-        An iterator of extracted links.
+        List of extracted links.
 
     See Also:
         * :func:`darc.parse._check`
@@ -383,11 +295,10 @@ def extract_links(link: str, html: typing.Union[str, bytes], check: bool = CHECK
     for child in soup.find_all(lambda tag: tag.has_attr('href') or tag.has_attr('src')):
         if (href := child.get('href', child.get('src'))) is None:
             continue
-        temp_list.append(urljoin(link, href))
+        temp_link = parse_link(urljoin(link.url, href))
+        temp_list.append(temp_link)
 
     # check content / proxy type
     if check:
-        link_list = _check(temp_list)
-    else:
-        link_list = temp_list.copy()
-    yield from set(link_list)
+        return _check(temp_list)
+    return temp_list
