@@ -223,7 +223,7 @@ def read_sitemap(link: Link, text: str, check: bool = CHECK) -> typing.List[Link
     return temp_list
 
 
-def fetch_sitemap(link: Link):
+def fetch_sitemap(link: Link, force: bool = False):
     """Fetch sitemap.
 
     The function will first fetch the ``robots.txt``, then
@@ -231,17 +231,22 @@ def fetch_sitemap(link: Link):
 
     Args:
         link: Link object to fetch for its sitemaps.
+        force: Force refetch its sitemaps.
 
     Returns:
         Contents of ``robots.txt`` and sitemaps.
 
     See Also:
-        * :func:`darc.parse.read_robots`
-        * :func:`darc.parse.read_sitemap`
+        * :func:`darc.proxy.null.read_robots`
+        * :func:`darc.proxy.null.read_sitemap`
         * :func:`darc.parse.get_sitemap`
 
     """
-    robots_path = have_robots(link)
+    if force:
+        print(stem.util.term.format(f'[ROBOTS] Force refetch {link.url}',
+                                    stem.util.term.Color.YELLOW))  # pylint: disable=no-member
+
+    robots_path = None if force else have_robots(link)
     if robots_path is not None:
 
         print(stem.util.term.format(f'[ROBOTS] Cached {link.url}',
@@ -265,7 +270,7 @@ def fetch_sitemap(link: Link):
         if response.ok:
             ct_type = get_content_type(response)
             if ct_type not in ['text/text', 'text/plain']:
-                print(render_error(f'[ROBOTS] Unresolved content type on {robots_link.url} ({ct_type}',
+                print(render_error(f'[ROBOTS] Unresolved content type on {robots_link.url} ({ct_type})',
                                    stem.util.term.Color.RED), file=sys.stderr)  # pylint: disable=no-member
                 robots_text = ''
             else:
@@ -277,12 +282,16 @@ def fetch_sitemap(link: Link):
                                stem.util.term.Color.RED), file=sys.stderr)  # pylint: disable=no-member
             robots_text = ''
 
+    if force:
+        print(stem.util.term.format(f'[SITEMAP] Force refetch {link.url}',
+                                    stem.util.term.Color.YELLOW))  # pylint: disable=no-member
+
     sitemaps = read_robots(link, robots_text, host=link.host)
     for sitemap_link in sitemaps:
-        sitemap_path = have_sitemap(sitemap_link)
+        sitemap_path = None if force else have_sitemap(sitemap_link)
         if sitemap_path is not None:
 
-            print(stem.util.term.format(f'[SITEMAP] Cached {link.url}',
+            print(stem.util.term.format(f'[SITEMAP] Cached {sitemap_link.url}',
                                         stem.util.term.Color.YELLOW))  # pylint: disable=no-member
             with open(sitemap_path) as file:
                 sitemap_text = file.read()
@@ -315,7 +324,7 @@ def fetch_sitemap(link: Link):
                 sitemap_text = response.text
                 save_sitemap(sitemap_link, sitemap_text)
             else:
-                print(render_error(f'[SITEMAP] Unresolved content type on {sitemap_link.url} ({ct_type}',
+                print(render_error(f'[SITEMAP] Unresolved content type on {sitemap_link.url} ({ct_type})',
                                    stem.util.term.Color.RED), file=sys.stderr)  # pylint: disable=no-member
                 continue
 
