@@ -26,6 +26,7 @@ There are three submission events:
 """
 
 import base64
+import contextlib
 import dataclasses
 import glob
 import json
@@ -40,7 +41,7 @@ import stem.util.term
 
 import darc.typing as typing
 from darc.const import DEBUG, PATH_DB
-from darc.error import APIRequestFailed, render_error
+from darc.error import APIRequestFailed, DatabaseOperaionFailed, render_error
 from darc.link import Link
 from darc.model import (HostnameModel, HostsModel, RequestsHistoryModel, RequestsModel, RobotsModel,
                         SeleniumModel, SitemapModel, URLModel)
@@ -342,34 +343,39 @@ def submit_new_host(time: typing.Datetime, link: Link, partial: bool = False):
     hosts = get_hosts(link)
 
     if SAVE_DB:
-        model, _ = HostnameModel.get_or_create(hostname=link.host, defaults=dict(
-            proxy=HostnameModel.Proxy[link.proxy.upper()],
-            discovery=time,
-            last_seen=time,
-            alive=False,
-            since=time,
-        ))
+        try:
+            model, _ = HostnameModel.get_or_create(hostname=link.host, defaults=dict(
+                proxy=HostnameModel.Proxy[link.proxy.upper()],
+                discovery=time,
+                last_seen=time,
+                alive=False,
+                since=time,
+            ))
 
-        if robots is not None:
-            RobotsModel.create(
-                host=model,
-                timestamp=time,
-                document=base64.b64decode(robots['data']).decode(),
-            )
+            if robots is not None:
+                RobotsModel.create(
+                    host=model,
+                    timestamp=time,
+                    document=base64.b64decode(robots['data']).decode(),
+                )
 
-        if sitemap is not None:
-            SitemapModel.create(
-                host=model,
-                timestamp=time,
-                document=base64.b64decode(sitemap['data']).decode(),
-            )
+            if sitemap is not None:
+                SitemapModel.create(
+                    host=model,
+                    timestamp=time,
+                    document=base64.b64decode(sitemap['data']).decode(),
+                )
 
-        if hosts is not None:
-            HostsModel.create(
-                host=model,
-                timestamp=time,
-                document=base64.b64decode(hosts['data']).decode(),
-            )
+            if hosts is not None:
+                HostsModel.create(
+                    host=model,
+                    timestamp=time,
+                    document=base64.b64decode(hosts['data']).decode(),
+                )
+        except Exception as error:
+            warning = warnings.formatwarning(error, DatabaseOperaionFailed, __file__, 347,
+                                             'submit_new_host(...)')
+            print(render_error(warning, stem.util.term.Color.YELLOW), end='', file=sys.stderr)  # pylint: disable=no-member
 
     data = {
         '$PARTIAL$': partial,
@@ -491,6 +497,60 @@ def submit_requests(time: typing.Datetime, link: Link,
         * :func:`darc.crawl.crawler`
 
     """
+    if SAVE_DB:
+        try:
+            model, _ = HostnameModel.get_or_create(hostname=link.host, defaults=dict(
+                proxy=HostnameModel.Proxy[link.proxy.upper()],
+                discovery=time,
+                last_seen=time,
+                alive=False,
+                since=time,
+            ))
+
+            url, _ = URLModel.get_or_create(hash=link.name, defaults=dict(
+                url=link.url,
+                hostname=model,
+                proxy=URLModel.Proxy[link.proxy.upper()],
+                discovery=time,
+                last_seen=time,
+                alive=False,
+                since=time,
+            ))
+
+            model = RequestsModel.create(
+                url=url,
+                timestamp=time,
+                method=response.request.method,
+                document=content,
+                mime_type=mime_type,
+                is_html = html,
+                status_code=response.status_code,
+                reason=response.reason,
+                cookies=response.cookies.get_dict(),
+                session=response.cookies.get_dict(),
+                request=dict(response.request.headers),
+                response=dict(response.headers),
+            )
+
+            for index, history in enumerate(response.history):
+                RequestsHistoryModel.create(
+                    index=index,
+                    model=model,
+                    url=history.url,
+                    timestamp=time,
+                    method=history.request.method,
+                    document=history.content,
+                    status_code=history.status_code,
+                    reason=history.reason,
+                    cookies=history.cookies.get_dict(),
+                    request=dict(history.request.headers),
+                    response=dict(history.headers),
+                )
+        except Exception as error:
+            warning = warnings.formatwarning(error, DatabaseOperaionFailed, __file__, 502,
+                                             'submit_requests(...)')
+            print(render_error(warning, stem.util.term.Color.YELLOW), end='', file=sys.stderr)  # pylint: disable=no-member
+
     metadata = get_metadata(link)
     ts = time.isoformat()
 
@@ -499,47 +559,6 @@ def submit_requests(time: typing.Datetime, link: Link,
     else:
         path = f'{link.base}/{link.name}_{ts}.dat'
 
-    if SAVE_DB:
-        url, _ = URLModel.get_or_create(hash=link.name, defaults=dict(
-            url=link.url,
-            hostname=HostnameModel.get(HostnameModel.hostname == link.host),
-            proxy=URLModel.Proxy[link.proxy.upper()],
-            discovery=time,
-            last_seen=time,
-            alive=False,
-            since=time,
-        ))
-
-        model = RequestsModel.create(
-            url=url,
-            timestamp=time,
-            method=response.request.method,
-            document=content,
-            mime_type=mime_type,
-            is_html = html,
-            status_code=response.status_code,
-            reason=response.reason,
-            cookies=response.cookies.get_dict(),
-            session=response.cookies.get_dict(),
-            request=dict(response.request.headers),
-            response=dict(response.headers),
-        )
-
-        for index, history in enumerate(response.history):
-            RequestsHistoryModel.create(
-                index=index,
-                model=model,
-                url=history.url,
-                timestamp=time,
-                method=history.request.method,
-                document=history.content,
-                status_code=history.status_code,
-                reason=history.reason,
-                cookies=history.cookies.get_dict(),
-                request=dict(history.request.headers),
-                response=dict(history.headers),
-            )
-
     data = {
         '[metadata]': metadata,
         'Timestamp': ts,
@@ -657,6 +676,37 @@ def submit_selenium(time: typing.Datetime, link: Link,
         * :func:`darc.crawl.loader`
 
     """
+    if SAVE_DB:
+        try:
+            model, _ = HostnameModel.get_or_create(hostname=link.host, defaults=dict(
+                proxy=HostnameModel.Proxy[link.proxy.upper()],
+                discovery=time,
+                last_seen=time,
+                alive=False,
+                since=time,
+            ))
+
+            url, _ = URLModel.get_or_create(hash=link.name, defaults=dict(
+                url=link.url,
+                hostname=model,
+                proxy=URLModel.Proxy[link.proxy.upper()],
+                discovery=time,
+                last_seen=time,
+                alive=False,
+                since=time,
+            ))
+
+            SeleniumModel.create(
+                url=url,
+                timestamp=time,
+                document=html,
+                screenshot=base64.b64decode(screenshot),
+            )
+        except Exception as error:
+            warning = warnings.formatwarning(error, DatabaseOperaionFailed, __file__, 681,
+                                             'submit_selenium(...)')
+            print(render_error(warning, stem.util.term.Color.YELLOW), end='', file=sys.stderr)  # pylint: disable=no-member
+
     metadata = get_metadata(link)
     ts = time.isoformat()
 
@@ -668,14 +718,6 @@ def submit_selenium(time: typing.Datetime, link: Link,
             data=screenshot,
         )
 
-    if SAVE_DB:
-        SeleniumModel.create(
-            url=URLModel.get(URLModel.hash == link.name),
-            timestamp=time,
-            document=html,
-            screenshot=base64.b64decode(screenshot),
-        )
-
     data = {
         '[metadata]': metadata,
         'Timestamp': ts,
